@@ -1,7 +1,12 @@
 # Licensed under the MIT License
 # https://github.com/craigahobbs/unittest-parallel/blob/main/LICENSE
 
+"""
+unittest-parallel top-level script environment
+"""
+
 from .main import main
 
+
 if __name__ == '__main__': # pragma: no cover
     main()
