@@ -39,6 +39,8 @@ def main(argv=None):
                         help='One or more TestCase class has a setUpClass method')
     parser.add_argument('--module-fixtures', action='store_true', default=False,
                         help='One or more test module has a setUpModule method')
+    parser.add_argument('--disable-process-pooling', action='store_true', default=False,
+                        help='Do not reuse processes used to run test suites')
     group_unittest = parser.add_argument_group('unittest options')
     group_unittest.add_argument('-s', '--start-directory', metavar='START', default='.',
                                 help="Directory to start discovery ('.' default)")
@@ -102,7 +104,10 @@ def main(argv=None):
 
         # Run the tests in parallel
         start_time = time.perf_counter()
-        with multiprocessing.Pool(process_count) as pool, multiprocessing.Manager() as manager:
+        multiprocessing_context = multiprocessing.get_context(method='spawn')
+        maxtasksperchild = 1 if args.disable_process_pooling else None
+        with multiprocessing_context.Pool(process_count, maxtasksperchild=maxtasksperchild) as pool, \
+             multiprocessing.Manager() as manager:
             test_manager = ParallelTestManager(manager, args, temp_dir)
             results = pool.map(test_manager.run_tests, test_suites)
         stop_time = time.perf_counter()
